<?php

/**
 * 2007-2016 PrestaShop.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    Hennes Hervé <contact@h-hennes.fr>
 *  @copyright 2013-2017 Hennes Hervé
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  http://www.h-hennes.fr/blog/
 */

class Hh_DashModule extends ModuleCore
{

    public function __construct()
    {

        $this->name = 'hh_dashmodule';
        $this->displayName = 'HH dash module';
        $this->tab = '';
        $this->version = '0.1.0';
        $this->author = 'hhhennes';

        parent::__construct();
    }

    public function install()
    {
        if ( !parent::install()
             || !$this->registerHook('dashboardZoneTwo') // Ou dashboardZoneOne
             || !$this->registerHook('dashboardData')
             || !$this->registerHook('actionAdminControllerSetMedia')        
            ){
            return false;
        }

        return true;

    }

    public function uninstall()
    {
        return parent::uninstall();
    }
    
    /**
     * Ajout du js spécifique du module dans le dashboard
     */
    public function hookActionAdminControllerSetMedia()
    {
        if (get_class($this->context->controller) == 'AdminDashboardController') {
            $this->context->controller->addJs($this->_path.'views/js/'.$this->name.'.js');
        }
    }

    /**
     * Hook Dasboard Principale
     * @return type
     */
    public function hookDashboardZoneTwo()
    {
        if ( !$this->isCached('hookDashboardZoneTwo.tpl',$this->getCacheId()) ) {
            $this->context->smarty->assign('configForm',$this->renderConfigForm());
        }
        return $this->display(__FILE__, 'views/templates/hook/hookDashboardZoneTwo.tpl',$this->getCacheId());
    }

    /**
     * Hook de récupération des données
     * @param type $params
     */
    public function hookDashboardData($params)
    {
        /**
         * Paramètres envoyés par leur dashboard pour actualiser les stats
         */
        $from = $params['date_from'];
        $to = $params['date_to'];

        //Exemple de requête qui utilise les pramètres
        $customers = Db::getInstance()->executeS("SELECT DATE(date_add) AS date, COUNT(*) AS nbre "
                . "FROM " . _DB_PREFIX_ . "customer "
                . "WHERE DATE(date_add) >= '" . pSQL($from) . "' AND DATE(date_add) <= '" . pSQL($to) . "' "
                . "GROUP BY DATE(date_add)");

        //Renvoi de tous les types de données possibles
        return [
            'data_value' =>
            [
                'current_time' => time(),
                'customers' => $customers,
                'sample_data' => '<strong>Test de données fixe</strong>',
            ],
            'data_table' => $this->_getSampleDataTable(),
            'data_trends' => $this->_getSampleDataTrends(),
            'data_list_small' => $this->_getSampleDataListSmall(),
            'data_chart' => $this->_getSampleDataChart(), //A implémenter
        ];
    }

    /**
     * Données de test pour un dashboard de type Table
     * @return array
     */
    protected function _getSampleDataTable()
    {
        return [
            'table_hh_sample_table' => [
                //Header de la table
                'header' => [
                    //Champ(s) wrapper(s) optionnel(s)
                    ['title' => 'sample_column_1','class' => 'text-left' , 'wrapper_start' => '<strong>','wrapper_stop' => '</strong>'],
                    ['title' => 'sample_column_2','class' => 'text-left'],
                    ['title' => 'sample_column_2','class' => 'text-left'],
                ],
                //Corps de la table
                'body' => [
                   [
                       //Champ wrapper optionnel
                       ['id' => 'sample_column_1','value' => 'test value', 'class' => 'text-left'],
                       ['id' => 'sample_column_2','value' => 'test value column2', 'class' => 'text-left','wrapper_start' => '<strong>','wrapper_stop' => '</strong>'],
                       ['id' => 'sample_column_3','value' => 'test value column3', 'class' => 'text-left'],
                   ],
                   [
                       ['id' => 'sample_column_1','value' => 'test value row 2', 'class' => 'text-left'],
                       ['id' => 'sample_column_2','value' => 'test value row 2 column2', 'class' => 'text-left'],
                       ['id' => 'sample_column_3','value' => 'test value row 2 column3', 'class' => 'text-left'],
                   ],
                   [
                       ['id' => 'sample_column_1','value' => 'test value row 3', 'class' => 'text-left'],
                       ['id' => 'sample_column_2','value' => 'test value row 3 column2', 'class' => 'text-left'],
                       ['id' => 'sample_column_3','value' => 'test value row 3 column3', 'class' => 'text-left'],
                   ]
                ]
            ],
        ];
    }

    /**
     * Données de test pour un dashboard de type trends
     * @return array
     */
    protected function _getSampleDataTrends()
    {
        return [
            'dash_trend_sample_1' => [
                'way' => 'up',
                'value' => 3,
            ],
            'dash_trend_sample_2' => [
                'way' => 'down',
                'value' => 3,
            ]
        ];
    }

    /**
     * Données de test pour un dashboard de type list small
     * @return array
     */
    protected function _getSampleDataListSmall()
    {
        return [
            'dash_list_small_sample' => [
                   'key1 : ' => ' value1',
                   'key2 : ' => ' value2',
                   'key3 : ' => [ 'value1', 'value2'],
            ],
        ];
    }


    /**
     * Données de test pour un dashboard de type chart
     * @Todo : Comportement à traiter
     * @return array
     */
    protected function _getSampleDataChart()
    {
        return [
            //Graphique de type ligne
            'data_chart_sample_1' => [
                'chart_type' => 'sample_chart_line_model', //Nom de la fonction d'initialisation dans le fichier hh_dashmodule.js
                'chart_xaxis_label' => 'X axis Label',
                'chart_yaxis_label' => 'Y axis Label',
                'data' => [
                    [
                        'color' => '#7777ff',
                        'area' => true,
                        'values' => [
                            ['x' => '1', 'y' => 10],
                            ['x' => '2', 'y' => 20],
                            ['x' => '3', 'y' => 30],
                            ['x' => '4', 'y' => 60],
                        ]
                    ],
                ]
            ],
            'data_chart_sample_2' => [
                'chart_type' => 'sample_chart_bar_model', //Nom de la fonction d'initialisation dans le fichier hh_dashmodule.js
                'chart_xaxis_label' => 'X axis Label',
                'chart_yaxis_label' => 'Y axis Label',
                'data' => [
                    [
                        'values' => [
                            ['label' => '2017-09-20', 'value' => 10],
                            ['label' => '2017-09-21', 'value' => 20],
                            ['label' => '2017-09-22', 'value' => 15],
                            ['label' => '2017-09-23', 'value' => 7],
                            ['label' => '2017-09-24', 'value' => 35],
                        ]
                    ],
                ]
            ],
        ];
    }
    /**
     * Fonction spécifique aux modules Dashboard
     */
    public function renderConfigForm()
    {

        return 'Config form params';

    }

}
