/**
 * 2007-2016 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    Hennes Hervé <contact@h-hennes.fr>
 *  @copyright 2013-2016 Hennes Hervé
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  http://www.h-hennes.fr/blog/
 */

/**
 * La librairie utilisée est nvd3 : pour plus d'informations => http://nvd3.org/examples/index.html
 *  documentation : https://nvd3-community.github.io/nvd3/examples/documentation.html
 */

/**
 * Modèle d'exemple de graphique en ligne
 * @param string widget_name
 * @param array chart_details
 * @returns chart
 */
function sample_chart_line_model(widget_name, chart_details) {

    nv.addGraph(function () {
        var chart = nv.models.lineChart()
                .margin({left: 100})  //Adjust chart margins to give the x-axis some breathing room.
                .useInteractiveGuideline(true)  //We want nice looking tooltips and a guideline!
                .transitionDuration(350)  //how fast do you want the lines to transition?
                .showLegend(true)       //Show the legend, allowing users to turn on/off line series.
                .showYAxis(true)        //Show the y-axis
                .showXAxis(true)        //Show the x-axis
                ;

        //Chart x-axis settings        
        chart.xAxis
                .axisLabel(chart_details.chart_xaxis_label)
                .tickFormat(d3.format('d'));

        //Chart y-axis settings        
        chart.yAxis
                .axisLabel(chart_details.chart_yaxis_label)
                .tickFormat(d3.format('d'));

        d3.select('#data_chart_sample_1 svg')    //Select the <svg> element you want to render the chart in.   
                .datum(chart_details.data)         //Populate the <svg> element with chart data...
                .call(chart);          //Finally, render the chart!

        //Update the chart when window resizes.
        nv.utils.windowResize(function () {
            chart.update()
        });
        return chart;
    });
}
/**
 * Modèle d'exemple de graphique en barre
 * @param string widget_name
 * @param array chart_details
 * @returns chart
 */
function sample_chart_bar_model(widget_name, chart_details) {

    nv.addGraph(function () {
        var chart = nv.models.discreteBarChart()
                .x(function (d) {
                    return d.label
                })    //Specify the data accessors.
                .y(function (d) {
                    return parseInt(d.value)
                })
                .staggerLabels(true)    //Too many bars and not enough room? Try staggering labels.
                .tooltips(false)        //Don't show tooltips
                .showValues(true)       //...instead, show the bar value right on top of each bar.
                .transitionDuration(350)
                .valueFormat(d3.format('d'))
                ;
                
        //Chart x-axis settings        
        chart.xAxis.axisLabel(chart_details.chart_xaxis_label);

        //Chart y-axis settings        
        chart.yAxis
                .axisLabel(chart_details.chart_yaxis_label)
                .tickFormat(d3.format('d'));

        d3.select('#data_chart_sample_2 svg')
                .datum(chart_details.data)
                .call(chart);

        nv.utils.windowResize(chart.update);

        return chart;
    });
}
